==> ChimeraX-0.1.8-cp311-cp311-macosx_10_15_universal2.whl: chimerax/core/buildinfo.py <==
# vim: set expandtab shiftwidth=4 softtabstop=4:

# === UCSF ChimeraX Copyright ===
# Copyright 2022 Regents of the University of California. All rights reserved.
# The ChimeraX application is provided pursuant to the ChimeraX license
# agreement, which covers academic and commercial uses. For more details, see
# <http://www.rbvi.ucsf.edu/chimerax/docs/licensing.html>
#
# This particular file is part of the ChimeraX library. You can also
# redistribute and/or modify it under the terms of the GNU Lesser General
# Public License version 2.1 as published by the Free Software Foundation.
# For more details, see
# <https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html>
#
# THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
# EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. ADDITIONAL LIABILITY
# LIMITATIONS ARE DESCRIBED IN THE GNU LESSER GENERAL PUBLIC LICENSE
# 1.8 2.1
#
# This notice must be embedded in or attached to all copies, including partial
# copies, of the software or any revisions or derivations thereof.
# === UCSF ChimeraX Copyright ===

# information about the current build

version = "1.8" # Chimerax core version
commit = "e98e9b644ba7526149ea05388e21f40829d2c804"   # last commit
date = "2024-06-10 23:15:52 UTC"    # date of last commit
branch = "v1.8"   # (modified) branch of last commit
copyright = "© 2016-2024 Regents of the University of California.  All rights reserved."

# general information

synopsis = (
    "An application for molecular visualization and analysis,"
    " with an emphasis on molecular assemblies."
)

web_site = "http://www.rbvi.ucsf.edu/chimerax/"

==> ChimeraX-0.1.71-cp311-cp311-macosx_10_15_universal2.whl: chimerax/core/buildinfo.py <==
# vim: set expandtab shiftwidth=4 softtabstop=4:

# === UCSF ChimeraX Copyright ===
# Copyright 2022 Regents of the University of California. All rights reserved.
# The ChimeraX application is provided pursuant to the ChimeraX license
# agreement, which covers academic and commercial uses. For more details, see
# <http://www.rbvi.ucsf.edu/chimerax/docs/licensing.html>
#
# This particular file is part of the ChimeraX library. You can also
# redistribute and/or modify it under the terms of the GNU Lesser General
# Public License version 2.1 as published by the Free Software Foundation.
# For more details, see
# <https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html>
#
# THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
# EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. ADDITIONAL LIABILITY
# LIMITATIONS ARE DESCRIBED IN THE GNU LESSER GENERAL PUBLIC LICENSE
# 1.8.dev202401222158 2.1
#
# This notice must be embedded in or attached to all copies, including partial
# copies, of the software or any revisions or derivations thereof.
# === UCSF ChimeraX Copyright ===

# information about the current build

version = "1.8.dev202401222158" # Chimerax core version
commit = "276ca598f5ef304e5657ddad5604f6854bc31284"   # last commit
date = "2024-01-22 21:58:34 UTC"    # date of last commit
branch = "modified develop"   # (modified) branch of last commit
copyright = "© 2016-2024 Regents of the University of California.  All rights reserved."

# general information

synopsis = (
    "An application for molecular visualization and analysis,"
    " with an emphasis on molecular assemblies."
)

web_site = "http://www.rbvi.ucsf.edu/chimerax/"
